# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-07-13 04:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0011_auto_20180712_1039'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoboCollectionFdv',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('TAG', models.CharField(max_length=3, null=True)),
                ('FINANCIER_ID', models.CharField(max_length=50, null=True)),
                ('APPL_ID', models.CharField(max_length=50, null=True)),
                ('CUST_ID', models.CharField(max_length=50, null=True)),
                ('PRINCIPAL_PAID', models.IntegerField(null=True)),
                ('INTEREST_PAID', models.IntegerField(null=True)),
                ('BCC_PAID', models.IntegerField(null=True)),
                ('OTHER_PAID', models.IntegerField(null=True)),
                ('PREPAYPENALTY_PAID', models.IntegerField(null=True)),
                ('PRINCIPAL_DUE', models.IntegerField(null=True)),
                ('INTEREST_DUE', models.IntegerField(null=True)),
                ('BCC_DUE', models.IntegerField(null=True)),
                ('OTHER_DUE', models.IntegerField(null=True)),
                ('PREPAYPENALTY_DUE', models.IntegerField(null=True)),
                ('LPC_PAID', models.IntegerField(null=True)),
                ('LPC_DUE', models.IntegerField(null=True)),
                ('FORMAT', models.CharField(max_length=60, null=True)),
                ('TENTATIVE_FORECLOSURE_AMT', models.IntegerField(null=True)),
                ('PREPAYPENALTY_PERCENT', models.IntegerField(null=True)),
                ('PRINCIPAL_BALANCE', models.IntegerField(null=True)),
                ('INSTALLMENT', models.IntegerField(null=True)),
                ('PREPAYMENT_PENALTY', models.IntegerField(null=True)),
                ('UNBILLED_INSTALLMENT', models.IntegerField(null=True)),
                ('OVERDUE_CHARGES', models.IntegerField(null=True)),
                ('ADVICE_OUTSTANDING_REPAYMENT_FEE', models.IntegerField(null=True)),
                ('TOTAL_RECEIVABLE', models.IntegerField(null=True)),
                ('NET_TOTAL', models.IntegerField(null=True)),
                ('REFUNDS', models.IntegerField(null=True)),
                ('CLOSURE_DATE', models.DateField(null=True)),
                ('ACCRUED_PENAL_INTEREST', models.CharField(max_length=100, null=True)),
            ],
        ),
    ]
