# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-07 20:53
from __future__ import unicode_literals

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0005_auto_20180605_2040'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoboEitView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('LOAN_ACCT_NUM', models.CharField(max_length=64)),
                ('ACID', models.CharField(max_length=44)),
                ('ACCRUED_UPTO_DATE_CR', models.DateField()),
                ('ACCRUED_UPTO_DATE_DR', models.DateField()),
                ('LAST_ACCRUAL_RUN_DATE_CR', models.DateField()),
                ('LAST_ACCRUAL_RUN_DATE_DR', models.DateField()),
                ('NRML_ACCRUED_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_ACCRUED_AMOUNT_DR', models.BigIntegerField()),
                ('BOOKED_UPTO_DATE_CR', models.DateField()),
                ('BOOKED_UPTO_DATE_DR', models.DateField()),
                ('LAST_BOOK_RUN_DATE_CR', models.DateField()),
                ('LAST_BOOK_RUN_DATE_DR', models.DateField()),
                ('BOOK_FOR_REV_DATE_CR', models.DateField()),
                ('BOOK_FOR_REV_DATE_DR', models.DateField()),
                ('NRML_BOOKED_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_BOOKED_AMOUNT_DR', models.BigIntegerField()),
                ('INTEREST_CALC_UPTO_DATE_CR', models.DateField()),
                ('INTEREST_CALC_UPTO_DATE_DR', models.DateField()),
                ('NRML_INTEREST_AMOUNT_CR', models.BigIntegerField()),
                ('NRML_INTEREST_AMOUNT_DR', models.BigIntegerField()),
                ('LAST_INTEREST_RUN_DATE_CR', models.DateField()),
                ('LAST_INTEREST_RUN_DATE_DR', models.DateField()),
                ('NEXT_INT_RUN_DATE_DR', models.DateField()),
                ('NRML_INT_SUSPENSE_AMT_DR', models.BigIntegerField()),
                ('PENAL_ACCRUED_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_BOOKED_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_INTEREST_AMOUNT_DR', models.BigIntegerField()),
                ('PENAL_INT_SUSPENSE_AMT_DR', models.BigIntegerField()),
                ('ACCOUNT_PEGGED_FLG', models.CharField(max_length=1)),
                ('GAM_CREATION_TIME', models.DateField()),
                ('GAM_LAST_CHANGE_TIME', models.DateField()),
                ('EIT_CREATION_TIME', models.DateField()),
                ('EIT_LAST_CHANGE_TIME', models.DateField()),
            ],
        ),
        migrations.CreateModel(
            name='RoboLrsView',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('LOAN_ACCT_NUM', models.CharField(max_length=64)),
                ('ACID', models.CharField(max_length=44)),
                ('FLOW_ID', models.CharField(max_length=20)),
                ('NUM_OF_FLOWS', models.IntegerField()),
                ('FLOW_AMT', models.BigIntegerField()),
                ('NUM_OF_DMDS', models.IntegerField()),
                ('NEXT_DMD_DATE', models.DateField()),
                ('NEXT_INT_DMD_DATE', models.DateField()),
                ('CURRENT_INT_REC_FLG', models.CharField(max_length=1)),
                ('GAM_CREATION_TIME', models.DateField()),
                ('GAM_LAST_CHANGE_TIME', models.DateField()),
                ('LRS_CREATION_TIME', models.DateField()),
                ('LRS_LAST_CHANGE_TIME', models.DateField()),
            ],
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAC_CREATION_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 52, 57, 59855)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAC_LAST_CHANGE_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 13, 876361)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAM_CREATION_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 18, 923843)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generalaccount',
            name='GAM_LAST_CHANGE_TIME',
            field=models.DateField(default=datetime.datetime(2018, 6, 7, 20, 53, 23, 587761)),
            preserve_default=False,
        ),
    ]
